<?php
/**
 * Работа с объектами "Счет на оплату"
 *
 * Интернет-сайт получает объект "Счет на оплату" целиком в каждом уведомлении от PayQR о событиях, связанных с этим объектом. Интернет-сайт может сам реализовывать любые логики работы с объектом "Счет на оплату", но для упрощения написания собственного кода некоторые методы заранее подготовлены и представлены в рамках этого файла. Пользуйтесь ими при желании.
 */
 
class payqr_invoice
{
  var $data;
  var $cancel = false;
  var $livemode;

  function payqr_invoice($data, $livemode=false)
  {
    $this->data = $data;
    $this->livemode = $livemode;
  }

  /**
   * Проверяет режим работы полученного уведомления от PayQR (true - "боевой", false - "тестовый")
   * @return bool
   */
  function isLivemode()
  {
    return $this->livemode;
  }

  /**
   * Возвращает идентификатор PayQR конкретного объекта "Счет на оплату"
   * @return string
   */
  function getInvId()
  {
    payqr_logs::log('payqr_invoice::getInvId()');
    return isset($this->data->id) ? $this->data->id : 0;
  }

 /**
   * Возвращает номер счета в PayQR (так номер счета видит покупатель в приложении PayQR)
   * @return mixed
   */
  function getPayqrNumber()
  {
    payqr_logs::log('payqr_invoice::getPayqrNumber()');
    return $this->data->payqrNumber;
  }

  /**
   * Возвращает номер покупателя в PayQR (уникальный идентификатор покупателя, можно ориентироваться для начисления бонусов за повторные покупки через PayQR)
   * @return mixed
   */
  function getPayqrUserId()
  {
    payqr_logs::log('payqr_invoice::getPayqrUserId()');
    return $this->data->payqrUserId;
  }

  /**
   * Возвращает номер заказа интернет-сайта (orderId) из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getOrderId()
  {
    payqr_logs::log('payqr_invoice::getOrderId()');
    return isset($this->data->orderId) ? $this->data->orderId : 0;
  }

  /**
   * Передает номера заказа интернет-сайта (orderId) в объект PayQR "Счет на оплату"
   * @param $id
   * @return bool
   */
  function setOrderId($orderid)
  {
    payqr_logs::log('payqr_invoice::setOrderId('.$orderid.')');
    if (isset($this->data)) {
      $this->data->orderId = $orderid;
      return true;
    }
    return false;
  }

  /**
   * Возвращает сумму заказа из объекта PayQR "Счет на оплату"
   * @return float
   */
  function getAmount()
  {
    payqr_logs::log('payqr_invoice::getAmount()');
    return isset($this->data->amount) ? $this->data->amount : 0;
  }

  /**
   * Изменяет сумму заказа в объекте PayQR "Счет на оплату" (для случаев крайней необходимости)
   * @param $amount
   * @return bool
   */
  function setAmount($amount)
  {
    payqr_logs::log('payqr_invoice::setAmount('.$amount.')');
    if (isset($this->data)) {
      $this->data->amount = round($amount, 2);
      return true;
    }
    return false;
  }

  /**
   * Возвращает содержимое корзины из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getCart()
  {
    payqr_logs::log('payqr_invoice::getCart()');
    return isset($this->data->cart) ? $this->data->cart : false;
  }

  /**
   * Изменяет содержимое корзины в объекте PayQR "Счет на оплату"
   * @param $cart_obj
   * @return bool
   */
  function setCart($cart_obj)
  {
    payqr_logs::log('payqr_invoice::setCart($cart_obj)');
    if (isset($this->data)) {
      $this->data->cart = $cart_obj;
      return true;
    }
    return false;
  }

  /**
   * Возвращает данные покупателя из объекта PayQR "Счет на оплату"
   * @return object
   */
  function getCustomer()
  {
    payqr_logs::log('payqr_invoice::getCustomer()');
    return isset($this->data->customer) ? $this->data->customer : false;
  }

  /**
   * Возвращает адрес доставки из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getDelivery()
  {
    payqr_logs::log('payqr_invoice::getDelivery()');
    return isset($this->data->delivery) ? $this->data->delivery : false;
  }

  /**
   * Передает список способов доставки интернет-сайта в объект PayQR "Счет на оплату"
   *
   * $delivery_cases_array = [
   *  [
   *    'article' => '2001',
   *    'number' => '1.1',
   *    'name' => 'DHL',
   *    'description' => '1-2 дня',
   *    'amountFrom' => '0',
   *    'amountTo' => '70'
   *  ],
   *
   * ];
   *
   * @param $delivery_cases_array
   */
  function setDeliveryCases($delivery_cases_array)
  {
    payqr_logs::log('payqr_invoice::setDeliveryCases($delivery_cases_array)');
    if (isset($this->data) && count($delivery_cases_array) > 0) {
      $delivery_cases = array();
      foreach ($delivery_cases_array as $delivery) {
        $delivery_cases[] = payqr_base::json_decode(json_encode($delivery), false);
      }
      $this->data->deliveryCases = $delivery_cases;
      return true;
    }
    return false;
  }

  /**
   * Передает список пунктов самовывоза интернет-сайта в объект PayQR "Счет на оплату"
   *
   * $pick_points_cases_array = [
   *  [
   *    'article' => '1001',
   *    'number' => '1.1',
   *    'name' => 'Наш пункт самовывоза 1',
   *    'description' => 'с 10:00 до 22:00',
   *    'amountFrom' => '90',
   *    'amountTo' => '140',
   *  ],
   *
   * ];
   *
   * @param $delivery_cases_array
   */
  function setPickPointsCases($pick_points_cases_array)
  {
    payqr_logs::log('payqr_invoice::setDeliveryCases($pick_points_cases_array)');
    if (isset($this->data) && count($pick_points_cases_array) > 0) {
      $pick_points_cases = array();
      foreach ($pick_points_cases_array as $point) {
        $pick_points_cases[] = payqr_base::json_decode(json_encode($point), false);
      }
      $this->data->pickPoints = $pick_points_cases;
      return true;
    }
    return false;
  }

  /**
   * Возвращает выбранный покупаталем пункт самовывоза из объекта PayQR "Счет на оплату"
   * Выбранный пункт самовывоза полностью соответствует одной из записей в предложенных интернет-сайтом пунктах самовывоза.
   * 
   * @return bool
   */
  function getPickPoints()
  {
    payqr_logs::log('payqr_invoice::getPickPoints()');
    if(isset($this->data->pickPointsSelected)){
      return $this->data->pickPointsSelected;
    }
    return false;
  }

  /**
   * Возвращает выбранный покупаталем способ доставки из объекта PayQR "Счет на оплату"
   * Выбранный способ доставки полностью соответствует одной из записей в предложенных интернет-сайом способах доставки.
   *
   * @return bool
   */
  function getDeliveryCasesSelected()
  {
    payqr_logs::log('payqr_invoice::getDeliveryCasesSelected()');
    if(isset($this->data->deliveryCasesSelected)){
      return $this->data->deliveryCasesSelected;
    }
    return false;
  }

  /**
   * Возвращает промо-идентификатор, если его указал покупатель, из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getPromo()
  {
    payqr_logs::log('payqr_invoice::getPromo()');
    return $this->data->promo;
  }

 /**
   * Возвращает номер товарной группы (orderGroup) из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getOrderGroup()
  {
    payqr_logs::log('payqr_invoice::getOrderGroup()');
    return $this->data->orderGroup;
  }

  /**
   * Устанавливает номер товарной группы (orderGroup) из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function setOrderGroup($order_group)
  {
    payqr_logs::log('payqr_invoice::setOrderGroup()');
    $this->data->orderGroup = $order_group;
  }

  /**
   * Возвращает использованную служебную информацию (userData) из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getUserData()
  {
    payqr_logs::log('payqr_invoice::getUserData()');
    return $this->data->userData;
  }

  /**
   * Устанавливает служебную информацию (userData) из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function setUserData($userData)
  {
    payqr_logs::log('payqr_invoice::setUserData()');
    $this->data->userData = $userData;
  }

  /**
   * Возвращает срок ожидания оплаты этого счета из объекта PayQR "Счет на оплату"
   * @return mixed
   */
  function getConfirmWaitingInMinutes()
  {
    payqr_logs::log('payqr_invoice::getConfirmWaitingInMinutes()');
    return $this->data->confirmWaitingInMinutes;
  }

  /**
   * Изменяет срок ожидания оплаты этого счета в объекте PayQR "Счет на оплату"
   * @return mixed
   */
  function setConfirmWaitingInMinutes($min)
  {
    payqr_logs::log('payqr_invoice::setConfirmWaitingInMinutes()');
    if (isset($this->data)) {
      $this->data->confirmWaitingInMinutes = $min;
      return true;
    }
    return false;
  }

  /**
   * Отменяет заказ (счет) до его оплаты (не через отдельный запрос в PayQR, а ответом в PayQR на полученное уведомление как HTTP/1.1 409 Conflict, поэтому подходит для использования только на этапе получения уведомления о событии invoice.order.creating)
   */
  function cancelOrder()
  {
    payqr_logs::log('payqr_invoice::cancelOrder()');
    $this->cancel = true;
  }

  /**
   * Возвращает статус "Счета на оплату"
   * @return mixed
   */
  function getStatus()
  {
    return $this->data->status;
  }

} 