<?php
/**
 * Прием уведомлений от PayQR
 */

class payqr_receiver
{

  var $objectResponse; // объект уведомления

  var $objectOrder; // объект события

  function payqr_receiver()
  {
    $this->objectResponse = false;
    $this->objectOrder = false;
    $this->orderId = 0;
    $this->errors = array();
  }

  /**
   * Получаем уведомление
   */
  function receiving()
  {
    // Проверяем что уведомление действительно от PayQR (по секретному ключу SecretKeyIn)
    payqr_logs::log('payqr_receiver::receiving()');
    if (!payqr_authentication::checkHeader(SECRET_KEY_IN)) {
      // если уведомление пришло не от PayQR, вызываем исключение
      new payqr_exeption("Неверный параметр ['PQRSecretKey'] в header уведомления", 1);
      exit;
    }
    // Получаем данные из тела запроса
    $json = file_get_contents('php://input');
    // Получаем объект события из уведомления
    $this->objectEvent = payqr_base::json_decode($json);
    // Проверяем наличие свойства типа объекта
    if (!isset($this->objectEvent->object) || !isset($this->objectEvent->id) || !isset($this->objectEvent->type)) {
      new payqr_exeption("В уведомлении отстутствуют обязательные параметры object id type", 1, $json);
      exit;
    }
    // Сохраняем тип уведомления
    $this->type = $this->objectEvent->type;

    payqr_logs::log("invoice.type: " . $this->type);

    // В зависимости от того какого типа уведомление, создаем объект
    switch ($this->objectEvent->data->object) {
      case 'invoice':
        $this->objectOrder = new payqr_invoice($this->objectEvent->data, $this->objectEvent->livemode);
        break;
      case 'revert':
        $this->objectOrder = new payqr_revert($this->objectEvent->data, $this->objectEvent->livemode);
        break;
      default:
        new payqr_exeption("В уведомлении отстутствуют обязательные параметры object id type", 1, $json);
        return false;
    }
    payqr_logs::log("Идентификатор счета на оплату: " . $this->objectEvent->id);
    // если все прошло успешно, возвращаем идентификатор счета на оплату
    return $this->objectEvent->id;
  }

  /**
   * Ответ на уведомление
   */
  function response()
  {
    $this->validateResponse();
    header("PQRSecretKey:" . SECRET_KEY_OUT);
    if($this->objectOrder->cancel){ // если счет отмечен как отмененный
      header("HTTP/1.1 409 Conflict");
      payqr_logs::log('payqr_receiver::response() - Send HTTP/1.1 409 Conflict');
      return;
    }
    header("HTTP/1.1 200 OK");
    echo payqr_base::json_encode($this->objectEvent);
    payqr_logs::log('payqr_receiver::response()');
    payqr_logs::log(payqr_base::json_encode($this->objectEvent)."\n\r");
  }


  /**
   * Возвращает тип уведомления
   * @return mixed
   */
  function getType()
  {
    return $this->type;
  }

  /**
   * Проверяет наличие обязательных параметров в ответе
   * @return bool
   */
  function validateResponse()
  {
    switch($this->type){
      case 'invoice.order.creating':
        if(intval($this->objectOrder->getOrderId()) < 1 || strlen($this->objectOrder->getOrderId())==0){
          payqr_logs::log('Критическая ошибка: интернет-сайт не указал уникальный номер созданного заказа (orderId) в ответе на уведомление invoice.order.creating', 'payqr_receiver::validateResponse()');
          return false;
        }
    }
    return true;
  }

} 